# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/serverless/containers/v1/container_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.serverless.containers.v1 import container_pb2 as yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=yandex/cloud/serverless/containers/v1/container_service.proto\x12%yandex.cloud.serverless.containers.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x35yandex/cloud/serverless/containers/v1/container.proto\x1a\x1dyandex/cloud/validation.proto\"1\n\x13GetContainerRequest\x12\x1a\n\x0c\x63ontainer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"g\n\x15ListContainersRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\"w\n\x16ListContainersResponse\x12\x44\n\ncontainers\x18\x01 \x03(\x0b\x32\x30.yandex.cloud.serverless.containers.v1.Container\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xd2\x02\n\x16\x43reateContainerRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9e\x01\n\x06labels\x18\x04 \x03(\x0b\x32I.yandex.cloud.serverless.containers.v1.CreateContainerRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"/\n\x17\x43reateContainerMetadata\x12\x14\n\x0c\x63ontainer_id\x18\x01 \x01(\t\"\x86\x03\n\x16UpdateContainerRequest\x12\x1a\n\x0c\x63ontainer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9e\x01\n\x06labels\x18\x05 \x03(\x0b\x32I.yandex.cloud.serverless.containers.v1.UpdateContainerRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"/\n\x17UpdateContainerMetadata\x12\x14\n\x0c\x63ontainer_id\x18\x01 \x01(\t\"4\n\x16\x44\x65leteContainerRequest\x12\x1a\n\x0c\x63ontainer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"/\n\x17\x44\x65leteContainerMetadata\x12\x14\n\x0c\x63ontainer_id\x18\x01 \x01(\t\"B\n\x1bGetContainerRevisionRequest\x12#\n\x15\x63ontainer_revision_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\xb3\x01\n\x1eListContainersRevisionsRequest\x12\x13\n\tfolder_id\x18\x01 \x01(\tH\x00\x12\x16\n\x0c\x63ontainer_id\x18\x02 \x01(\tH\x00\x12\x1d\n\tpage_size\x18\x03 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x05 \x01(\tB\n\x8a\xc8\x31\x06<=1000B\n\n\x02id\x12\x04\xc0\xc1\x31\x01\"~\n\x1fListContainersRevisionsResponse\x12\x42\n\trevisions\x18\x01 \x03(\x0b\x32/.yandex.cloud.serverless.containers.v1.Revision\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xa7\x06\n\x1e\x44\x65ployContainerRevisionRequest\x12\x1a\n\x0c\x63ontainer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12I\n\tresources\x18\x05 \x01(\x0b\x32\x30.yandex.cloud.serverless.containers.v1.ResourcesB\x04\xe8\xc7\x31\x01\x12@\n\x11\x65xecution_timeout\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\xc7\x31\x06<=600s\x12\x1a\n\x12service_account_id\x18\x07 \x01(\t\x12J\n\nimage_spec\x18\x08 \x01(\x0b\x32\x30.yandex.cloud.serverless.containers.v1.ImageSpecB\x04\xe8\xc7\x31\x01\x12\x13\n\x0b\x63oncurrency\x18\t \x01(\x03\x12>\n\x07secrets\x18\n \x03(\x0b\x32-.yandex.cloud.serverless.containers.v1.Secret\x12I\n\x0c\x63onnectivity\x18\x0b \x01(\x0b\x32\x33.yandex.cloud.serverless.containers.v1.Connectivity\x12P\n\x10provision_policy\x18\x0c \x01(\x0b\x32\x36.yandex.cloud.serverless.containers.v1.ProvisionPolicy\x12L\n\x0escaling_policy\x18\r \x01(\x0b\x32\x34.yandex.cloud.serverless.containers.v1.ScalingPolicy\x12\x46\n\x0blog_options\x18\x0e \x01(\x0b\x32\x31.yandex.cloud.serverless.containers.v1.LogOptions\x12K\n\x0estorage_mounts\x18\x0f \x03(\x0b\x32\x33.yandex.cloud.serverless.containers.v1.StorageMountJ\x04\x08\x04\x10\x05J\x04\x08\x02\x10\x03\"\xe8\x02\n\tImageSpec\x12\x17\n\timage_url\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12?\n\x07\x63ommand\x18\x02 \x01(\x0b\x32..yandex.cloud.serverless.containers.v1.Command\x12\x39\n\x04\x61rgs\x18\x03 \x01(\x0b\x32+.yandex.cloud.serverless.containers.v1.Args\x12}\n\x0b\x65nvironment\x18\x04 \x03(\x0b\x32\x41.yandex.cloud.serverless.containers.v1.ImageSpec.EnvironmentEntryB%\x8a\xc8\x31\x06<=4096\xb2\xc8\x31\x17\x12\x15[a-zA-Z][a-zA-Z0-9_]*\x12\x13\n\x0bworking_dir\x18\x05 \x01(\t\x1a\x32\n\x10\x45nvironmentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"@\n\x1f\x44\x65ployContainerRevisionMetadata\x12\x1d\n\x15\x63ontainer_revision_id\x18\x01 \x01(\t\"Q\n\x18RollbackContainerRequest\x12\x1a\n\x0c\x63ontainer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x19\n\x0brevision_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"F\n\x19RollbackContainerMetadata\x12\x14\n\x0c\x63ontainer_id\x18\x01 \x01(\t\x12\x13\n\x0brevision_id\x18\x02 \x01(\t\"\x96\x01\n\x1eListContainerOperationsRequest\x12\x1a\n\x0c\x63ontainer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"q\n\x1fListContainerOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xed\x14\n\x10\x43ontainerService\x12\xa5\x01\n\x03Get\x12:.yandex.cloud.serverless.containers.v1.GetContainerRequest\x1a\x30.yandex.cloud.serverless.containers.v1.Container\"0\x82\xd3\xe4\x93\x02*\x12(/containers/v1/containers/{container_id}\x12\xa6\x01\n\x04List\x12<.yandex.cloud.serverless.containers.v1.ListContainersRequest\x1a=.yandex.cloud.serverless.containers.v1.ListContainersResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/containers/v1/containers\x12\xb8\x01\n\x06\x43reate\x12=.yandex.cloud.serverless.containers.v1.CreateContainerRequest\x1a!.yandex.cloud.operation.Operation\"L\xb2\xd2*$\n\x17\x43reateContainerMetadata\x12\tContainer\x82\xd3\xe4\x93\x02\x1e\"\x19/containers/v1/containers:\x01*\x12\xc7\x01\n\x06Update\x12=.yandex.cloud.serverless.containers.v1.UpdateContainerRequest\x1a!.yandex.cloud.operation.Operation\"[\xb2\xd2*$\n\x17UpdateContainerMetadata\x12\tContainer\x82\xd3\xe4\x93\x02-2(/containers/v1/containers/{container_id}:\x01*\x12\xd0\x01\n\x06\x44\x65lete\x12=.yandex.cloud.serverless.containers.v1.DeleteContainerRequest\x1a!.yandex.cloud.operation.Operation\"d\xb2\xd2*0\n\x17\x44\x65leteContainerMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02**(/containers/v1/containers/{container_id}\x12\xd5\x01\n\x0e\x44\x65ployRevision\x12\x45.yandex.cloud.serverless.containers.v1.DeployContainerRevisionRequest\x1a!.yandex.cloud.operation.Operation\"Y\xb2\xd2*+\n\x1f\x44\x65ployContainerRevisionMetadata\x12\x08Revision\x82\xd3\xe4\x93\x02$\"\x1f/containers/v1/revisions:deploy:\x01*\x12\xd6\x01\n\x08Rollback\x12?.yandex.cloud.serverless.containers.v1.RollbackContainerRequest\x1a!.yandex.cloud.operation.Operation\"f\xb2\xd2*&\n\x19RollbackContainerMetadata\x12\tContainer\x82\xd3\xe4\x93\x02\x36\"1/containers/v1/containers/{container_id}:rollback:\x01*\x12\xbc\x01\n\x0bGetRevision\x12\x42.yandex.cloud.serverless.containers.v1.GetContainerRevisionRequest\x1a/.yandex.cloud.serverless.containers.v1.Revision\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/containers/v1/revisions/{container_revision_id}\x12\xc0\x01\n\rListRevisions\x12\x45.yandex.cloud.serverless.containers.v1.ListContainersRevisionsRequest\x1a\x46.yandex.cloud.serverless.containers.v1.ListContainersRevisionsResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/containers/v1/revisions\x12\xdc\x01\n\x0eListOperations\x12\x45.yandex.cloud.serverless.containers.v1.ListContainerOperationsRequest\x1a\x46.yandex.cloud.serverless.containers.v1.ListContainerOperationsResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/containers/v1/containers/{container_id}/operations\x12\xb9\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"B\x82\xd3\xe4\x93\x02<\x12:/containers/v1/containers/{resource_id}:listAccessBindings\x12\xe9\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x81\x01\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02>\"9/containers/v1/containers/{resource_id}:setAccessBindings:\x01*\x12\xf5\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x87\x01\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x41\"</containers/v1/containers/{resource_id}:updateAccessBindings:\x01*B\x81\x01\n)yandex.cloud.api.serverless.containers.v1ZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/containers/v1;containersb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.containers.v1.container_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)yandex.cloud.api.serverless.containers.v1ZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/containers/v1;containers'
  _GETCONTAINERREQUEST.fields_by_name['container_id']._options = None
  _GETCONTAINERREQUEST.fields_by_name['container_id']._serialized_options = b'\350\3071\001'
  _LISTCONTAINERSREQUEST.fields_by_name['folder_id']._options = None
  _LISTCONTAINERSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _CREATECONTAINERREQUEST_LABELSENTRY._options = None
  _CREATECONTAINERREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATECONTAINERREQUEST.fields_by_name['folder_id']._options = None
  _CREATECONTAINERREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _CREATECONTAINERREQUEST.fields_by_name['name']._options = None
  _CREATECONTAINERREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _CREATECONTAINERREQUEST.fields_by_name['description']._options = None
  _CREATECONTAINERREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATECONTAINERREQUEST.fields_by_name['labels']._options = None
  _CREATECONTAINERREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _UPDATECONTAINERREQUEST_LABELSENTRY._options = None
  _UPDATECONTAINERREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATECONTAINERREQUEST.fields_by_name['container_id']._options = None
  _UPDATECONTAINERREQUEST.fields_by_name['container_id']._serialized_options = b'\350\3071\001'
  _UPDATECONTAINERREQUEST.fields_by_name['name']._options = None
  _UPDATECONTAINERREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _UPDATECONTAINERREQUEST.fields_by_name['description']._options = None
  _UPDATECONTAINERREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATECONTAINERREQUEST.fields_by_name['labels']._options = None
  _UPDATECONTAINERREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _DELETECONTAINERREQUEST.fields_by_name['container_id']._options = None
  _DELETECONTAINERREQUEST.fields_by_name['container_id']._serialized_options = b'\350\3071\001'
  _GETCONTAINERREVISIONREQUEST.fields_by_name['container_revision_id']._options = None
  _GETCONTAINERREVISIONREQUEST.fields_by_name['container_revision_id']._serialized_options = b'\350\3071\001'
  _LISTCONTAINERSREVISIONSREQUEST.oneofs_by_name['id']._options = None
  _LISTCONTAINERSREVISIONSREQUEST.oneofs_by_name['id']._serialized_options = b'\300\3011\001'
  _LISTCONTAINERSREVISIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTCONTAINERSREVISIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTCONTAINERSREVISIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTCONTAINERSREVISIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTCONTAINERSREVISIONSREQUEST.fields_by_name['filter']._options = None
  _LISTCONTAINERSREVISIONSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _DEPLOYCONTAINERREVISIONREQUEST.fields_by_name['container_id']._options = None
  _DEPLOYCONTAINERREVISIONREQUEST.fields_by_name['container_id']._serialized_options = b'\350\3071\001'
  _DEPLOYCONTAINERREVISIONREQUEST.fields_by_name['resources']._options = None
  _DEPLOYCONTAINERREVISIONREQUEST.fields_by_name['resources']._serialized_options = b'\350\3071\001'
  _DEPLOYCONTAINERREVISIONREQUEST.fields_by_name['execution_timeout']._options = None
  _DEPLOYCONTAINERREVISIONREQUEST.fields_by_name['execution_timeout']._serialized_options = b'\372\3071\006<=600s'
  _DEPLOYCONTAINERREVISIONREQUEST.fields_by_name['image_spec']._options = None
  _DEPLOYCONTAINERREVISIONREQUEST.fields_by_name['image_spec']._serialized_options = b'\350\3071\001'
  _IMAGESPEC_ENVIRONMENTENTRY._options = None
  _IMAGESPEC_ENVIRONMENTENTRY._serialized_options = b'8\001'
  _IMAGESPEC.fields_by_name['image_url']._options = None
  _IMAGESPEC.fields_by_name['image_url']._serialized_options = b'\350\3071\001'
  _IMAGESPEC.fields_by_name['environment']._options = None
  _IMAGESPEC.fields_by_name['environment']._serialized_options = b'\212\3101\006<=4096\262\3101\027\022\025[a-zA-Z][a-zA-Z0-9_]*'
  _ROLLBACKCONTAINERREQUEST.fields_by_name['container_id']._options = None
  _ROLLBACKCONTAINERREQUEST.fields_by_name['container_id']._serialized_options = b'\350\3071\001'
  _ROLLBACKCONTAINERREQUEST.fields_by_name['revision_id']._options = None
  _ROLLBACKCONTAINERREQUEST.fields_by_name['revision_id']._serialized_options = b'\350\3071\001'
  _LISTCONTAINEROPERATIONSREQUEST.fields_by_name['container_id']._options = None
  _LISTCONTAINEROPERATIONSREQUEST.fields_by_name['container_id']._serialized_options = b'\350\3071\001'
  _LISTCONTAINEROPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTCONTAINEROPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTCONTAINEROPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTCONTAINEROPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTCONTAINEROPERATIONSREQUEST.fields_by_name['filter']._options = None
  _LISTCONTAINEROPERATIONSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _CONTAINERSERVICE.methods_by_name['Get']._options = None
  _CONTAINERSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002*\022(/containers/v1/containers/{container_id}'
  _CONTAINERSERVICE.methods_by_name['List']._options = None
  _CONTAINERSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\033\022\031/containers/v1/containers'
  _CONTAINERSERVICE.methods_by_name['Create']._options = None
  _CONTAINERSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*$\n\027CreateContainerMetadata\022\tContainer\202\323\344\223\002\036\"\031/containers/v1/containers:\001*'
  _CONTAINERSERVICE.methods_by_name['Update']._options = None
  _CONTAINERSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*$\n\027UpdateContainerMetadata\022\tContainer\202\323\344\223\002-2(/containers/v1/containers/{container_id}:\001*'
  _CONTAINERSERVICE.methods_by_name['Delete']._options = None
  _CONTAINERSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*0\n\027DeleteContainerMetadata\022\025google.protobuf.Empty\202\323\344\223\002**(/containers/v1/containers/{container_id}'
  _CONTAINERSERVICE.methods_by_name['DeployRevision']._options = None
  _CONTAINERSERVICE.methods_by_name['DeployRevision']._serialized_options = b'\262\322*+\n\037DeployContainerRevisionMetadata\022\010Revision\202\323\344\223\002$\"\037/containers/v1/revisions:deploy:\001*'
  _CONTAINERSERVICE.methods_by_name['Rollback']._options = None
  _CONTAINERSERVICE.methods_by_name['Rollback']._serialized_options = b'\262\322*&\n\031RollbackContainerMetadata\022\tContainer\202\323\344\223\0026\"1/containers/v1/containers/{container_id}:rollback:\001*'
  _CONTAINERSERVICE.methods_by_name['GetRevision']._options = None
  _CONTAINERSERVICE.methods_by_name['GetRevision']._serialized_options = b'\202\323\344\223\0022\0220/containers/v1/revisions/{container_revision_id}'
  _CONTAINERSERVICE.methods_by_name['ListRevisions']._options = None
  _CONTAINERSERVICE.methods_by_name['ListRevisions']._serialized_options = b'\202\323\344\223\002\032\022\030/containers/v1/revisions'
  _CONTAINERSERVICE.methods_by_name['ListOperations']._options = None
  _CONTAINERSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0025\0223/containers/v1/containers/{container_id}/operations'
  _CONTAINERSERVICE.methods_by_name['ListAccessBindings']._options = None
  _CONTAINERSERVICE.methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002<\022:/containers/v1/containers/{resource_id}:listAccessBindings'
  _CONTAINERSERVICE.methods_by_name['SetAccessBindings']._options = None
  _CONTAINERSERVICE.methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002>\"9/containers/v1/containers/{resource_id}:setAccessBindings:\001*'
  _CONTAINERSERVICE.methods_by_name['UpdateAccessBindings']._options = None
  _CONTAINERSERVICE.methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002A\"</containers/v1/containers/{resource_id}:updateAccessBindings:\001*'
  _globals['_GETCONTAINERREQUEST']._serialized_start=394
  _globals['_GETCONTAINERREQUEST']._serialized_end=443
  _globals['_LISTCONTAINERSREQUEST']._serialized_start=445
  _globals['_LISTCONTAINERSREQUEST']._serialized_end=548
  _globals['_LISTCONTAINERSRESPONSE']._serialized_start=550
  _globals['_LISTCONTAINERSRESPONSE']._serialized_end=669
  _globals['_CREATECONTAINERREQUEST']._serialized_start=672
  _globals['_CREATECONTAINERREQUEST']._serialized_end=1010
  _globals['_CREATECONTAINERREQUEST_LABELSENTRY']._serialized_start=965
  _globals['_CREATECONTAINERREQUEST_LABELSENTRY']._serialized_end=1010
  _globals['_CREATECONTAINERMETADATA']._serialized_start=1012
  _globals['_CREATECONTAINERMETADATA']._serialized_end=1059
  _globals['_UPDATECONTAINERREQUEST']._serialized_start=1062
  _globals['_UPDATECONTAINERREQUEST']._serialized_end=1452
  _globals['_UPDATECONTAINERREQUEST_LABELSENTRY']._serialized_start=965
  _globals['_UPDATECONTAINERREQUEST_LABELSENTRY']._serialized_end=1010
  _globals['_UPDATECONTAINERMETADATA']._serialized_start=1454
  _globals['_UPDATECONTAINERMETADATA']._serialized_end=1501
  _globals['_DELETECONTAINERREQUEST']._serialized_start=1503
  _globals['_DELETECONTAINERREQUEST']._serialized_end=1555
  _globals['_DELETECONTAINERMETADATA']._serialized_start=1557
  _globals['_DELETECONTAINERMETADATA']._serialized_end=1604
  _globals['_GETCONTAINERREVISIONREQUEST']._serialized_start=1606
  _globals['_GETCONTAINERREVISIONREQUEST']._serialized_end=1672
  _globals['_LISTCONTAINERSREVISIONSREQUEST']._serialized_start=1675
  _globals['_LISTCONTAINERSREVISIONSREQUEST']._serialized_end=1854
  _globals['_LISTCONTAINERSREVISIONSRESPONSE']._serialized_start=1856
  _globals['_LISTCONTAINERSREVISIONSRESPONSE']._serialized_end=1982
  _globals['_DEPLOYCONTAINERREVISIONREQUEST']._serialized_start=1985
  _globals['_DEPLOYCONTAINERREVISIONREQUEST']._serialized_end=2792
  _globals['_IMAGESPEC']._serialized_start=2795
  _globals['_IMAGESPEC']._serialized_end=3155
  _globals['_IMAGESPEC_ENVIRONMENTENTRY']._serialized_start=3105
  _globals['_IMAGESPEC_ENVIRONMENTENTRY']._serialized_end=3155
  _globals['_DEPLOYCONTAINERREVISIONMETADATA']._serialized_start=3157
  _globals['_DEPLOYCONTAINERREVISIONMETADATA']._serialized_end=3221
  _globals['_ROLLBACKCONTAINERREQUEST']._serialized_start=3223
  _globals['_ROLLBACKCONTAINERREQUEST']._serialized_end=3304
  _globals['_ROLLBACKCONTAINERMETADATA']._serialized_start=3306
  _globals['_ROLLBACKCONTAINERMETADATA']._serialized_end=3376
  _globals['_LISTCONTAINEROPERATIONSREQUEST']._serialized_start=3379
  _globals['_LISTCONTAINEROPERATIONSREQUEST']._serialized_end=3529
  _globals['_LISTCONTAINEROPERATIONSRESPONSE']._serialized_start=3531
  _globals['_LISTCONTAINEROPERATIONSRESPONSE']._serialized_end=3644
  _globals['_CONTAINERSERVICE']._serialized_start=3647
  _globals['_CONTAINERSERVICE']._serialized_end=6316
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/video/v1/manifest.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$yandex/cloud/video/v1/manifest.proto\x12\x15yandex.cloud.video.v1\"\x95\x01\n\x08Manifest\x12\x0b\n\x03url\x18\x01 \x01(\t\x12:\n\x04type\x18\x02 \x01(\x0e\x32,.yandex.cloud.video.v1.Manifest.ManifestType\"@\n\x0cManifestType\x12\x1d\n\x19MANIFEST_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04\x44\x41SH\x10\x01\x12\x07\n\x03HLS\x10\x02\x42\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.manifest_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _globals['_MANIFEST']._serialized_start=64
  _globals['_MANIFEST']._serialized_end=213
  _globals['_MANIFEST_MANIFESTTYPE']._serialized_start=149
  _globals['_MANIFEST_MANIFESTTYPE']._serialized_end=213
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/dataproc/manager/v1/manager_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/dataproc/manager/v1/manager_service.proto\x12 yandex.cloud.dataproc.manager.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"_\n\rHbaseNodeInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08requests\x18\x02 \x01(\x03\x12\x14\n\x0cheap_size_mb\x18\x03 \x01(\x03\x12\x18\n\x10max_heap_size_mb\x18\x04 \x01(\x03\"\xe1\x01\n\tHbaseInfo\x12\x11\n\tavailable\x18\x01 \x01(\x08\x12\x0f\n\x07regions\x18\x02 \x01(\x03\x12\x10\n\x08requests\x18\x03 \x01(\x03\x12\x14\n\x0c\x61verage_load\x18\x04 \x01(\x01\x12\x43\n\nlive_nodes\x18\x05 \x03(\x0b\x32/.yandex.cloud.dataproc.manager.v1.HbaseNodeInfo\x12\x43\n\ndead_nodes\x18\x06 \x03(\x0b\x32/.yandex.cloud.dataproc.manager.v1.HbaseNodeInfo\"r\n\x0cHDFSNodeInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04used\x18\x02 \x01(\x03\x12\x11\n\tremaining\x18\x03 \x01(\x03\x12\x10\n\x08\x63\x61pacity\x18\x04 \x01(\x03\x12\x12\n\nnum_blocks\x18\x05 \x01(\x03\x12\r\n\x05state\x18\x06 \x01(\t\"\x89\x04\n\x08HDFSInfo\x12\x11\n\tavailable\x18\x01 \x01(\x08\x12\x19\n\x11percent_remaining\x18\x02 \x01(\x01\x12\x0c\n\x04used\x18\x03 \x01(\x03\x12\x0c\n\x04\x66ree\x18\x04 \x01(\x03\x12\x14\n\x0ctotal_blocks\x18\x05 \x01(\x03\x12\x16\n\x0emissing_blocks\x18\x06 \x01(\x03\x12\"\n\x1amissing_blocks_replica_one\x18\x07 \x01(\x03\x12\x42\n\nlive_nodes\x18\x08 \x03(\x0b\x32..yandex.cloud.dataproc.manager.v1.HDFSNodeInfo\x12\x42\n\ndead_nodes\x18\t \x03(\x0b\x32..yandex.cloud.dataproc.manager.v1.HDFSNodeInfo\x12\x10\n\x08safemode\x18\x0b \x01(\t\x12M\n\x15\x64\x65\x63ommissioning_nodes\x18\x0c \x03(\x0b\x32..yandex.cloud.dataproc.manager.v1.HDFSNodeInfo\x12L\n\x14\x64\x65\x63ommissioned_nodes\x18\r \x03(\x0b\x32..yandex.cloud.dataproc.manager.v1.HDFSNodeInfo\x12$\n\x1crequested_decommission_hosts\x18\x0e \x03(\tJ\x04\x08\n\x10\x0b\"\x9b\x01\n\x08HiveInfo\x12\x11\n\tavailable\x18\x01 \x01(\x08\x12\x19\n\x11queries_succeeded\x18\x02 \x01(\x03\x12\x16\n\x0equeries_failed\x18\x03 \x01(\x03\x12\x19\n\x11queries_executing\x18\x04 \x01(\x03\x12\x15\n\rsessions_open\x18\x05 \x01(\x03\x12\x17\n\x0fsessions_active\x18\x06 \x01(\x03\"\x8d\x01\n\x0cYarnNodeInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05state\x18\x02 \x01(\t\x12\x16\n\x0enum_containers\x18\x03 \x01(\x03\x12\x16\n\x0eused_memory_mb\x18\x04 \x01(\x03\x12\x1b\n\x13\x61vailable_memory_mb\x18\x05 \x01(\x03\x12\x13\n\x0bupdate_time\x18\x06 \x01(\x03\"\x87\x01\n\x08YarnInfo\x12\x11\n\tavailable\x18\x01 \x01(\x08\x12\x42\n\nlive_nodes\x18\x02 \x03(\x0b\x32..yandex.cloud.dataproc.manager.v1.YarnNodeInfo\x12$\n\x1crequested_decommission_hosts\x18\x03 \x03(\t\"\x1e\n\rZookeeperInfo\x12\r\n\x05\x61live\x18\x01 \x01(\x08\"\x1a\n\tOozieInfo\x12\r\n\x05\x61live\x18\x01 \x01(\x08\"\x19\n\x08LivyInfo\x12\r\n\x05\x61live\x18\x01 \x01(\x08\"Y\n\x08InitActs\x12>\n\x05state\x18\x01 \x01(\x0e\x32/.yandex.cloud.dataproc.manager.v1.InitActsState\x12\r\n\x05\x66qdns\x18\x02 \x03(\t\"\xff\x03\n\x04Info\x12\x38\n\x04hdfs\x18\x01 \x01(\x0b\x32*.yandex.cloud.dataproc.manager.v1.HDFSInfo\x12\x38\n\x04yarn\x18\x02 \x01(\x0b\x32*.yandex.cloud.dataproc.manager.v1.YarnInfo\x12\x38\n\x04hive\x18\x03 \x01(\x0b\x32*.yandex.cloud.dataproc.manager.v1.HiveInfo\x12\x42\n\tzookeeper\x18\x04 \x01(\x0b\x32/.yandex.cloud.dataproc.manager.v1.ZookeeperInfo\x12:\n\x05hbase\x18\x05 \x01(\x0b\x32+.yandex.cloud.dataproc.manager.v1.HbaseInfo\x12:\n\x05oozie\x18\x06 \x01(\x0b\x32+.yandex.cloud.dataproc.manager.v1.OozieInfo\x12\x14\n\x0creport_count\x18\x07 \x01(\x03\x12\x38\n\x04livy\x18\x08 \x01(\x0b\x32*.yandex.cloud.dataproc.manager.v1.LivyInfo\x12=\n\tinit_acts\x18\t \x01(\x0b\x32*.yandex.cloud.dataproc.manager.v1.InitActs\"\x9f\x01\n\rReportRequest\x12\x0b\n\x03\x63id\x18\x01 \x01(\t\x12\x19\n\x11topology_revision\x18\x02 \x01(\x03\x12\x34\n\x04info\x18\x03 \x01(\x0b\x32&.yandex.cloud.dataproc.manager.v1.Info\x12\x30\n\x0c\x63ollected_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"s\n\x0bReportReply\x12\x1c\n\x14\x64\x65\x63ommission_timeout\x18\x01 \x01(\x03\x12\"\n\x1ayarn_hosts_to_decommission\x18\x02 \x03(\t\x12\"\n\x1ahdfs_hosts_to_decommission\x18\x03 \x03(\t*]\n\rInitActsState\x12\x1f\n\x1bINIT_ACTS_STATE_UNSPECIFIED\x10\x00\x12\n\n\x06\x46\x41ILED\x10\x01\x12\x0e\n\nSUCCESSFUL\x10\x02\x12\x0f\n\x0bIN_PROGRESS\x10\x03\x32\x84\x01\n\x16\x44\x61taprocManagerService\x12j\n\x06Report\x12/.yandex.cloud.dataproc.manager.v1.ReportRequest\x1a-.yandex.cloud.dataproc.manager.v1.ReportReply\"\x00\x42}\n$yandex.cloud.api.dataproc.manager.v1ZUgithub.com/yandex-cloud/go-genproto/yandex/cloud/dataproc/manager/v1;dataproc_managerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.dataproc.manager.v1.manager_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$yandex.cloud.api.dataproc.manager.v1ZUgithub.com/yandex-cloud/go-genproto/yandex/cloud/dataproc/manager/v1;dataproc_manager'
  _globals['_INITACTSSTATE']._serialized_start=2501
  _globals['_INITACTSSTATE']._serialized_end=2594
  _globals['_HBASENODEINFO']._serialized_start=125
  _globals['_HBASENODEINFO']._serialized_end=220
  _globals['_HBASEINFO']._serialized_start=223
  _globals['_HBASEINFO']._serialized_end=448
  _globals['_HDFSNODEINFO']._serialized_start=450
  _globals['_HDFSNODEINFO']._serialized_end=564
  _globals['_HDFSINFO']._serialized_start=567
  _globals['_HDFSINFO']._serialized_end=1088
  _globals['_HIVEINFO']._serialized_start=1091
  _globals['_HIVEINFO']._serialized_end=1246
  _globals['_YARNNODEINFO']._serialized_start=1249
  _globals['_YARNNODEINFO']._serialized_end=1390
  _globals['_YARNINFO']._serialized_start=1393
  _globals['_YARNINFO']._serialized_end=1528
  _globals['_ZOOKEEPERINFO']._serialized_start=1530
  _globals['_ZOOKEEPERINFO']._serialized_end=1560
  _globals['_OOZIEINFO']._serialized_start=1562
  _globals['_OOZIEINFO']._serialized_end=1588
  _globals['_LIVYINFO']._serialized_start=1590
  _globals['_LIVYINFO']._serialized_end=1615
  _globals['_INITACTS']._serialized_start=1617
  _globals['_INITACTS']._serialized_end=1706
  _globals['_INFO']._serialized_start=1709
  _globals['_INFO']._serialized_end=2220
  _globals['_REPORTREQUEST']._serialized_start=2223
  _globals['_REPORTREQUEST']._serialized_end=2382
  _globals['_REPORTREPLY']._serialized_start=2384
  _globals['_REPORTREPLY']._serialized_end=2499
  _globals['_DATAPROCMANAGERSERVICE']._serialized_start=2597
  _globals['_DATAPROCMANAGERSERVICE']._serialized_end=2729
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/containerregistry/v1/ip_permission.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5yandex/cloud/containerregistry/v1/ip_permission.proto\x12!yandex.cloud.containerregistry.v1\x1a\x1dyandex/cloud/validation.proto\"\x98\x01\n\x0cIpPermission\x12\x46\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32\x36.yandex.cloud.containerregistry.v1.IpPermission.Action\x12\n\n\x02ip\x18\x02 \x01(\t\"4\n\x06\x41\x63tion\x12\x16\n\x12\x41\x43TION_UNSPECIFIED\x10\x00\x12\x08\n\x04PULL\x10\x01\x12\x08\n\x04PUSH\x10\x02\"\xae\x01\n\x11IpPermissionDelta\x12K\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32\x35.yandex.cloud.containerregistry.v1.IpPermissionActionB\x04\xe8\xc7\x31\x01\x12L\n\rip_permission\x18\x02 \x01(\x0b\x32/.yandex.cloud.containerregistry.v1.IpPermissionB\x04\xe8\xc7\x31\x01*O\n\x12IpPermissionAction\x12$\n IP_PERMISSION_ACTION_UNSPECIFIED\x10\x00\x12\x07\n\x03\x41\x44\x44\x10\x01\x12\n\n\x06REMOVE\x10\x02\x42\x80\x01\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.containerregistry.v1.ip_permission_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistry'
  _IPPERMISSIONDELTA.fields_by_name['action']._options = None
  _IPPERMISSIONDELTA.fields_by_name['action']._serialized_options = b'\350\3071\001'
  _IPPERMISSIONDELTA.fields_by_name['ip_permission']._options = None
  _IPPERMISSIONDELTA.fields_by_name['ip_permission']._serialized_options = b'\350\3071\001'
  _globals['_IPPERMISSIONACTION']._serialized_start=455
  _globals['_IPPERMISSIONACTION']._serialized_end=534
  _globals['_IPPERMISSION']._serialized_start=124
  _globals['_IPPERMISSION']._serialized_end=276
  _globals['_IPPERMISSION_ACTION']._serialized_start=224
  _globals['_IPPERMISSION_ACTION']._serialized_end=276
  _globals['_IPPERMISSIONDELTA']._serialized_start=279
  _globals['_IPPERMISSIONDELTA']._serialized_end=453
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import yandex.cloud.kms.v1.symmetric_key_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class SymmetricEncryptRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    AAD_CONTEXT_FIELD_NUMBER: builtins.int
    PLAINTEXT_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the symmetric KMS key to use for encryption."""
    version_id: builtins.str
    """ID of the key version to encrypt plaintext with.
    Defaults to the primary version if not specified.
    """
    aad_context: builtins.bytes
    """Additional authenticated data (AAD context), optional.
    If specified, this data will be required for decryption with the [SymmetricDecryptRequest].
    Should be encoded with base64.
    """
    plaintext: builtins.bytes
    """Plaintext to be encrypted.
    Should be encoded with base64.
    """
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        version_id: builtins.str = ...,
        aad_context: builtins.bytes = ...,
        plaintext: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["aad_context", b"aad_context", "key_id", b"key_id", "plaintext", b"plaintext", "version_id", b"version_id"]) -> None: ...

global___SymmetricEncryptRequest = SymmetricEncryptRequest

@typing.final
class SymmetricEncryptResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    CIPHERTEXT_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the symmetric KMS key that was used for encryption."""
    version_id: builtins.str
    """ID of the key version that was used for encryption."""
    ciphertext: builtins.bytes
    """Resulting ciphertext."""
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        version_id: builtins.str = ...,
        ciphertext: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["ciphertext", b"ciphertext", "key_id", b"key_id", "version_id", b"version_id"]) -> None: ...

global___SymmetricEncryptResponse = SymmetricEncryptResponse

@typing.final
class SymmetricDecryptRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    AAD_CONTEXT_FIELD_NUMBER: builtins.int
    CIPHERTEXT_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the symmetric KMS key to use for decryption."""
    aad_context: builtins.bytes
    """Additional authenticated data, must be the same as was provided
    in the corresponding [SymmetricEncryptRequest].
    Should be encoded with base64.
    """
    ciphertext: builtins.bytes
    """Ciphertext to be decrypted.
    Should be encoded with base64.
    """
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        aad_context: builtins.bytes = ...,
        ciphertext: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["aad_context", b"aad_context", "ciphertext", b"ciphertext", "key_id", b"key_id"]) -> None: ...

global___SymmetricDecryptRequest = SymmetricDecryptRequest

@typing.final
class SymmetricDecryptResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    PLAINTEXT_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the symmetric KMS key that was used for decryption."""
    version_id: builtins.str
    """ID of the key version that was used for decryption."""
    plaintext: builtins.bytes
    """Decrypted plaintext."""
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        version_id: builtins.str = ...,
        plaintext: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id", "plaintext", b"plaintext", "version_id", b"version_id"]) -> None: ...

global___SymmetricDecryptResponse = SymmetricDecryptResponse

@typing.final
class GenerateDataKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    AAD_CONTEXT_FIELD_NUMBER: builtins.int
    DATA_KEY_SPEC_FIELD_NUMBER: builtins.int
    SKIP_PLAINTEXT_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the symmetric KMS key that the generated data key should be encrypted with."""
    version_id: builtins.str
    """ID of the key version to encrypt the generated data key with.
    Defaults to the primary version if not specified.
    """
    aad_context: builtins.bytes
    """Additional authenticated data (AAD context), optional.
    If specified, this data will be required for decryption with the [SymmetricDecryptRequest].
    Should be encoded with base64.
    """
    data_key_spec: yandex.cloud.kms.v1.symmetric_key_pb2.SymmetricAlgorithm.ValueType
    """Encryption algorithm and key length for the generated data key."""
    skip_plaintext: builtins.bool
    """If `true`, the method won't return the data key as plaintext.
    Default value is `false`.
    """
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        version_id: builtins.str = ...,
        aad_context: builtins.bytes = ...,
        data_key_spec: yandex.cloud.kms.v1.symmetric_key_pb2.SymmetricAlgorithm.ValueType = ...,
        skip_plaintext: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["aad_context", b"aad_context", "data_key_spec", b"data_key_spec", "key_id", b"key_id", "skip_plaintext", b"skip_plaintext", "version_id", b"version_id"]) -> None: ...

global___GenerateDataKeyRequest = GenerateDataKeyRequest

@typing.final
class GenerateDataKeyResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    DATA_KEY_PLAINTEXT_FIELD_NUMBER: builtins.int
    DATA_KEY_CIPHERTEXT_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the symmetric KMS key that was used to encrypt the generated data key."""
    version_id: builtins.str
    """ID of the key version that was used for encryption."""
    data_key_plaintext: builtins.bytes
    """Generated data key as plaintext.
    The field is empty, if the [GenerateDataKeyRequest.skip_plaintext] parameter
    was set to `true`.
    """
    data_key_ciphertext: builtins.bytes
    """The encrypted data key."""
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        version_id: builtins.str = ...,
        data_key_plaintext: builtins.bytes = ...,
        data_key_ciphertext: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["data_key_ciphertext", b"data_key_ciphertext", "data_key_plaintext", b"data_key_plaintext", "key_id", b"key_id", "version_id", b"version_id"]) -> None: ...

global___GenerateDataKeyResponse = GenerateDataKeyResponse

@typing.final
class SymmetricReEncryptRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    AAD_CONTEXT_FIELD_NUMBER: builtins.int
    SOURCE_KEY_ID_FIELD_NUMBER: builtins.int
    SOURCE_AAD_CONTEXT_FIELD_NUMBER: builtins.int
    CIPHERTEXT_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the new key to be used for encryption."""
    version_id: builtins.str
    """ID of the version of the new key to be used for encryption.
    Defaults to the primary version if not specified.
    """
    aad_context: builtins.bytes
    """Additional authenticated data to be required for decryption.
    Should be encoded with base64.
    """
    source_key_id: builtins.str
    """ID of the key that the ciphertext is currently encrypted with. May be the same as for the new key."""
    source_aad_context: builtins.bytes
    """Additional authenticated data provided with the initial encryption request.
    Should be encoded with base64.
    """
    ciphertext: builtins.bytes
    """Ciphertext to re-encrypt.
    Should be encoded with base64.
    """
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        version_id: builtins.str = ...,
        aad_context: builtins.bytes = ...,
        source_key_id: builtins.str = ...,
        source_aad_context: builtins.bytes = ...,
        ciphertext: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["aad_context", b"aad_context", "ciphertext", b"ciphertext", "key_id", b"key_id", "source_aad_context", b"source_aad_context", "source_key_id", b"source_key_id", "version_id", b"version_id"]) -> None: ...

global___SymmetricReEncryptRequest = SymmetricReEncryptRequest

@typing.final
class SymmetricReEncryptResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    SOURCE_KEY_ID_FIELD_NUMBER: builtins.int
    SOURCE_VERSION_ID_FIELD_NUMBER: builtins.int
    CIPHERTEXT_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the key that the ciphertext is encrypted with now."""
    version_id: builtins.str
    """ID of key version that was used for encryption."""
    source_key_id: builtins.str
    """ID of the key that the ciphertext was encrypted with previously."""
    source_version_id: builtins.str
    """ID of the key version that was used to decrypt the re-encrypted ciphertext."""
    ciphertext: builtins.bytes
    """Resulting re-encrypted ciphertext."""
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        version_id: builtins.str = ...,
        source_key_id: builtins.str = ...,
        source_version_id: builtins.str = ...,
        ciphertext: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["ciphertext", b"ciphertext", "key_id", b"key_id", "source_key_id", b"source_key_id", "source_version_id", b"source_version_id", "version_id", b"version_id"]) -> None: ...

global___SymmetricReEncryptResponse = SymmetricReEncryptResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.struct_pb2
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Versioning:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _VersioningEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Versioning.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    VERSIONING_UNSPECIFIED: _Versioning.ValueType  # 0
    VERSIONING_DISABLED: _Versioning.ValueType  # 1
    """The bucket is unversioned, i.e. versioning has never been enabled for the bucket, including at its creation.
    Objects that are stored in the bucket have a version ID of `null`.

    To enable versioning, change status to `VERSIONING_ENABLED` via a [BucketService.Update] request. Note that this
    action is irreversible, and a bucket with versioning enabled can never return to `VERSIONING_DISABLED` state.
    """
    VERSIONING_ENABLED: _Versioning.ValueType  # 2
    """Bucket versioning is enabled, i.e. all new objects are versioned and given a unique version ID, and objects that
    already existed at the time versioning was enabled will be versioned and given a unique version ID when modified
    by future requests.

    To suspend versioning, change status to `VERSIONING_SUSPENDED` via a [BucketService.Update] request. You cannot
    disable versioning altogether for a bucket that already had it enabled; objects that had version IDs will keep
    them.
    """
    VERSIONING_SUSPENDED: _Versioning.ValueType  # 3
    """Bucket versioning is suspended, i.e. new objects are not versioned, but objects that already existed at the time
    versioning was suspended are still versioned and keep their version IDs.

    To resume versioning, change status to `VERSIONING_ENABLED` via a [BucketService.Update] request.
    """

class Versioning(_Versioning, metaclass=_VersioningEnumTypeWrapper): ...

VERSIONING_UNSPECIFIED: Versioning.ValueType  # 0
VERSIONING_DISABLED: Versioning.ValueType  # 1
"""The bucket is unversioned, i.e. versioning has never been enabled for the bucket, including at its creation.
Objects that are stored in the bucket have a version ID of `null`.

To enable versioning, change status to `VERSIONING_ENABLED` via a [BucketService.Update] request. Note that this
action is irreversible, and a bucket with versioning enabled can never return to `VERSIONING_DISABLED` state.
"""
VERSIONING_ENABLED: Versioning.ValueType  # 2
"""Bucket versioning is enabled, i.e. all new objects are versioned and given a unique version ID, and objects that
already existed at the time versioning was enabled will be versioned and given a unique version ID when modified
by future requests.

To suspend versioning, change status to `VERSIONING_SUSPENDED` via a [BucketService.Update] request. You cannot
disable versioning altogether for a bucket that already had it enabled; objects that had version IDs will keep
them.
"""
VERSIONING_SUSPENDED: Versioning.ValueType  # 3
"""Bucket versioning is suspended, i.e. new objects are not versioned, but objects that already existed at the time
versioning was suspended are still versioned and keep their version IDs.

To resume versioning, change status to `VERSIONING_ENABLED` via a [BucketService.Update] request.
"""
global___Versioning = Versioning

@typing.final
class Bucket(google.protobuf.message.Message):
    """A bucket resource.
    For details about the concept, see [documentation](/docs/storage/concepts/bucket).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    ANONYMOUS_ACCESS_FLAGS_FIELD_NUMBER: builtins.int
    DEFAULT_STORAGE_CLASS_FIELD_NUMBER: builtins.int
    VERSIONING_FIELD_NUMBER: builtins.int
    MAX_SIZE_FIELD_NUMBER: builtins.int
    POLICY_FIELD_NUMBER: builtins.int
    ACL_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    CORS_FIELD_NUMBER: builtins.int
    WEBSITE_SETTINGS_FIELD_NUMBER: builtins.int
    LIFECYCLE_RULES_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    OBJECT_LOCK_FIELD_NUMBER: builtins.int
    ENCRYPTION_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the bucket. Always equal to [name], which has priority."""
    name: builtins.str
    """Name of the bucket.

    The name is unique within the platform. For naming limitations and rules, see
    [documentation](/docs/storage/concepts/bucket#naming).
    """
    folder_id: builtins.str
    """ID of the folder that the bucket belongs to."""
    default_storage_class: builtins.str
    """Default storage class for objects in the bucket. Supported classes are standard storage (`STANDARD`), cold storage
    (`COLD`, `STANDARD_IA`, `NEARLINE` all synonyms), and ice storage (`ICE` and `GLACIER` are synonyms).
    For details, see [documentation](/docs/storage/concepts/storage-class).
    """
    versioning: global___Versioning.ValueType
    """Bucket versioning status.
    For details, see [documentation](/docs/storage/concepts/versioning).
    """
    max_size: builtins.int
    """Maximum size of the bucket, in bytes.
    For details, see [documentation](/docs/storage/operations/buckets/limit-max-volume).
    """
    @property
    def anonymous_access_flags(self) -> global___AnonymousAccessFlags:
        """Flags for configuring public (anonymous) access to the bucket's content and settings.
        For details, see [documentation](/docs/storage/concepts/bucket#bucket-access).
        """

    @property
    def policy(self) -> google.protobuf.struct_pb2.Struct:
        """Bucket policies that set permissions for actions with the bucket, its objects, and groups of objects.
        For details, see [documentation](/docs/storage/concepts/policy).
        """

    @property
    def acl(self) -> global___ACL:
        """Access control list (ACL) of the bucket.
        For details, see [documentation](/docs/storage/concepts/acl).
        """

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def cors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CorsRule]:
        """List of rules for cross-domain requests to objects in the bucket (cross-origin resource sharing, CORS).
        For details, see [documentation](/docs/storage/concepts/cors).
        """

    @property
    def website_settings(self) -> global___WebsiteSettings:
        """Configuration for hosting a static website in the bucket.
        For details, see [documentation](/docs/storage/concepts/hosting).
        """

    @property
    def lifecycle_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LifecycleRule]:
        """List of object lifecycle rules for the bucket.
        For details, see [documentation](/docs/storage/concepts/lifecycles).
        """

    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Tag]:
        """List of tags for the bucket.
        For details, see [documentation](/docs/resource-manager/concepts/labels).
        """

    @property
    def object_lock(self) -> global___ObjectLock:
        """Configuration for object lock on the bucket.
        For details about the concept, see [documentation](/docs/storage/concepts/object-lock).
        """

    @property
    def encryption(self) -> global___Encryption:
        """Configuration for bucket's encryption
        For detauls, see [documentation](/docs/storage/concepts/encryption)
        """

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        folder_id: builtins.str = ...,
        anonymous_access_flags: global___AnonymousAccessFlags | None = ...,
        default_storage_class: builtins.str = ...,
        versioning: global___Versioning.ValueType = ...,
        max_size: builtins.int = ...,
        policy: google.protobuf.struct_pb2.Struct | None = ...,
        acl: global___ACL | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        cors: collections.abc.Iterable[global___CorsRule] | None = ...,
        website_settings: global___WebsiteSettings | None = ...,
        lifecycle_rules: collections.abc.Iterable[global___LifecycleRule] | None = ...,
        tags: collections.abc.Iterable[global___Tag] | None = ...,
        object_lock: global___ObjectLock | None = ...,
        encryption: global___Encryption | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["acl", b"acl", "anonymous_access_flags", b"anonymous_access_flags", "created_at", b"created_at", "encryption", b"encryption", "object_lock", b"object_lock", "policy", b"policy", "website_settings", b"website_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["acl", b"acl", "anonymous_access_flags", b"anonymous_access_flags", "cors", b"cors", "created_at", b"created_at", "default_storage_class", b"default_storage_class", "encryption", b"encryption", "folder_id", b"folder_id", "id", b"id", "lifecycle_rules", b"lifecycle_rules", "max_size", b"max_size", "name", b"name", "object_lock", b"object_lock", "policy", b"policy", "tags", b"tags", "versioning", b"versioning", "website_settings", b"website_settings"]) -> None: ...

global___Bucket = Bucket

@typing.final
class Tag(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    key: builtins.str
    """Key of the bucket tag."""
    value: builtins.str
    """Value of the bucket tag."""
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

global___Tag = Tag

@typing.final
class ACL(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Grant(google.protobuf.message.Message):
        """A grant resource, used to specify the permission granted and the grantee."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Permission:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _PermissionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ACL.Grant._Permission.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            PERMISSION_UNSPECIFIED: ACL.Grant._Permission.ValueType  # 0
            PERMISSION_FULL_CONTROL: ACL.Grant._Permission.ValueType  # 1
            """Allows grantee the `PERMISSION_WRITE`, `PERMISSION_WRITE_ACP`, `PERMISSION_READ`, and `PERMISSION_READ_ACP`
            on the bucket.

            Maps to `x-amz-grant-full-control` header for [bucketPutAcl](/docs/storage/s3/api-ref/acl/bucketput) method of
            Amazon S3-compatible HTTP API.
            """
            PERMISSION_WRITE: ACL.Grant._Permission.ValueType  # 2
            """Allows grantee to create new objects in the bucket. For the bucket and object owners of existing objects, also
            allows deletions and overwrites of those objects.

            Maps to `x-amz-grant-write` header for [bucketPutAcl](/docs/storage/s3/api-ref/acl/bucketput) method of Amazon
            S3-compatible HTTP API.
            """
            PERMISSION_WRITE_ACP: ACL.Grant._Permission.ValueType  # 3
            """Allows grantee to write the ACL for the bucket.

            Maps to `x-amz-grant-write-acp` header for [bucketPutAcl](/docs/storage/s3/api-ref/acl/bucketput) method of
            Amazon S3-compatible HTTP API.
            """
            PERMISSION_READ: ACL.Grant._Permission.ValueType  # 4
            """Allows grantee to list the objects in the bucket.

            Maps to `x-amz-grant-read` header for [bucketPutAcl](/docs/storage/s3/api-ref/acl/bucketput) method of Amazon
            S3-compatible HTTP API.
            """
            PERMISSION_READ_ACP: ACL.Grant._Permission.ValueType  # 5
            """Allows grantee to read the bucket ACL

            Maps to `x-amz-grant-read-acp` header for [bucketPutAcl](/docs/storage/s3/api-ref/acl/bucketput) method of
            Amazon S3-compatible HTTP API.
            """

        class Permission(_Permission, metaclass=_PermissionEnumTypeWrapper): ...
        PERMISSION_UNSPECIFIED: ACL.Grant.Permission.ValueType  # 0
        PERMISSION_FULL_CONTROL: ACL.Grant.Permission.ValueType  # 1
        """Allows grantee the `PERMISSION_WRITE`, `PERMISSION_WRITE_ACP`, `PERMISSION_READ`, and `PERMISSION_READ_ACP`
        on the bucket.

        Maps to `x-amz-grant-full-control` header for [bucketPutAcl](/docs/storage/s3/api-ref/acl/bucketput) method of
        Amazon S3-compatible HTTP API.
        """
        PERMISSION_WRITE: ACL.Grant.Permission.ValueType  # 2
        """Allows grantee to create new objects in the bucket. For the bucket and object owners of existing objects, also
        allows deletions and overwrites of those objects.

        Maps to `x-amz-grant-write` header for [bucketPutAcl](/docs/storage/s3/api-ref/acl/bucketput) method of Amazon
        S3-compatible HTTP API.
        """
        PERMISSION_WRITE_ACP: ACL.Grant.Permission.ValueType  # 3
        """Allows grantee to write the ACL for the bucket.

        Maps to `x-amz-grant-write-acp` header for [bucketPutAcl](/docs/storage/s3/api-ref/acl/bucketput) method of
        Amazon S3-compatible HTTP API.
        """
        PERMISSION_READ: ACL.Grant.Permission.ValueType  # 4
        """Allows grantee to list the objects in the bucket.

        Maps to `x-amz-grant-read` header for [bucketPutAcl](/docs/storage/s3/api-ref/acl/bucketput) method of Amazon
        S3-compatible HTTP API.
        """
        PERMISSION_READ_ACP: ACL.Grant.Permission.ValueType  # 5
        """Allows grantee to read the bucket ACL

        Maps to `x-amz-grant-read-acp` header for [bucketPutAcl](/docs/storage/s3/api-ref/acl/bucketput) method of
        Amazon S3-compatible HTTP API.
        """

        class _GrantType:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _GrantTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ACL.Grant._GrantType.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            GRANT_TYPE_UNSPECIFIED: ACL.Grant._GrantType.ValueType  # 0
            GRANT_TYPE_ACCOUNT: ACL.Grant._GrantType.ValueType  # 1
            """A grantee is an [account on the platform](/docs/iam/concepts/#accounts).

            For this grantee type, you need to specify the user ID in [Bucket.acl.grants.grantee_id] field. To get user ID, see
            [instruction](/docs/iam/operations/users/get).

            Maps to using `id="*"` value for `x-amz-grant-*` header ([bucketPutAcl](/docs/storage/s3/api-ref/acl/bucketput)
            method of Amazon S3-compatible HTTP API).
            """
            GRANT_TYPE_ALL_AUTHENTICATED_USERS: ACL.Grant._GrantType.ValueType  # 2
            """Grantees are all authenticated users, both from your clouds and other users' clouds. Access
            permission to this group allows any account on the platform to access the resource via a signed (authenticated)
            request.

            Maps to using `uri="http://acs.amazonaws.com/groups/global/AuthenticatedUsers"` value for `x-amz-grant-*`
            header ([bucketPutAcl](/docs/storage/s3/api-ref/acl/bucketput) method of Amazon S3-compatible HTTP API).
            """
            GRANT_TYPE_ALL_USERS: ACL.Grant._GrantType.ValueType  # 3
            """Grantees are all internet users. Access permission to this group allows anyone in the world access to the
            resource via signed (authenticated) or unsigned (anonymous) requests.

            Maps to using `uri="http://acs.amazonaws.com/groups/global/AllUsers"` value for `x-amz-grant-*` header
            ([bucketPutAcl](/docs/storage/s3/api-ref/acl/bucketput) method of Amazon S3-compatible HTTP API).
            """

        class GrantType(_GrantType, metaclass=_GrantTypeEnumTypeWrapper): ...
        GRANT_TYPE_UNSPECIFIED: ACL.Grant.GrantType.ValueType  # 0
        GRANT_TYPE_ACCOUNT: ACL.Grant.GrantType.ValueType  # 1
        """A grantee is an [account on the platform](/docs/iam/concepts/#accounts).

        For this grantee type, you need to specify the user ID in [Bucket.acl.grants.grantee_id] field. To get user ID, see
        [instruction](/docs/iam/operations/users/get).

        Maps to using `id="*"` value for `x-amz-grant-*` header ([bucketPutAcl](/docs/storage/s3/api-ref/acl/bucketput)
        method of Amazon S3-compatible HTTP API).
        """
        GRANT_TYPE_ALL_AUTHENTICATED_USERS: ACL.Grant.GrantType.ValueType  # 2
        """Grantees are all authenticated users, both from your clouds and other users' clouds. Access
        permission to this group allows any account on the platform to access the resource via a signed (authenticated)
        request.

        Maps to using `uri="http://acs.amazonaws.com/groups/global/AuthenticatedUsers"` value for `x-amz-grant-*`
        header ([bucketPutAcl](/docs/storage/s3/api-ref/acl/bucketput) method of Amazon S3-compatible HTTP API).
        """
        GRANT_TYPE_ALL_USERS: ACL.Grant.GrantType.ValueType  # 3
        """Grantees are all internet users. Access permission to this group allows anyone in the world access to the
        resource via signed (authenticated) or unsigned (anonymous) requests.

        Maps to using `uri="http://acs.amazonaws.com/groups/global/AllUsers"` value for `x-amz-grant-*` header
        ([bucketPutAcl](/docs/storage/s3/api-ref/acl/bucketput) method of Amazon S3-compatible HTTP API).
        """

        PERMISSION_FIELD_NUMBER: builtins.int
        GRANT_TYPE_FIELD_NUMBER: builtins.int
        GRANTEE_ID_FIELD_NUMBER: builtins.int
        permission: global___ACL.Grant.Permission.ValueType
        """Permission granted by the grant."""
        grant_type: global___ACL.Grant.GrantType.ValueType
        """The grantee type for the grant."""
        grantee_id: builtins.str
        """ID of the account who is a grantee. Required when the [grant_type] is `GRANT_TYPE_ACCOUNT`."""
        def __init__(
            self,
            *,
            permission: global___ACL.Grant.Permission.ValueType = ...,
            grant_type: global___ACL.Grant.GrantType.ValueType = ...,
            grantee_id: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["grant_type", b"grant_type", "grantee_id", b"grantee_id", "permission", b"permission"]) -> None: ...

    GRANTS_FIELD_NUMBER: builtins.int
    @property
    def grants(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ACL.Grant]:
        """List of permissions granted and the grantees."""

    def __init__(
        self,
        *,
        grants: collections.abc.Iterable[global___ACL.Grant] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["grants", b"grants"]) -> None: ...

global___ACL = ACL

@typing.final
class AnonymousAccessFlags(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    READ_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    CONFIG_READ_FIELD_NUMBER: builtins.int
    @property
    def read(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Specifies whether public (anonymous) access to read objects in the bucket is enabled."""

    @property
    def list(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Specifies whether public (anonymous) access to the list of objects in the bucket is enabled."""

    @property
    def config_read(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Specifies whether public (anonymous) access to read [CORS](/docs/storage/concepts/cors),
        [static website hosting](/docs/storage/concepts/hosting), and
        [object lifecycles](/docs/storage/concepts/lifecycles) settings of the bucket is enabled.
        """

    def __init__(
        self,
        *,
        read: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        list: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        config_read: google.protobuf.wrappers_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["config_read", b"config_read", "list", b"list", "read", b"read"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["config_read", b"config_read", "list", b"list", "read", b"read"]) -> None: ...

global___AnonymousAccessFlags = AnonymousAccessFlags

@typing.final
class CorsRule(google.protobuf.message.Message):
    """A CORS rule resource.
    For details about the concept, see [documentation](/docs/storage/concepts/cors).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Method:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _MethodEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[CorsRule._Method.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        METHOD_UNSPECIFIED: CorsRule._Method.ValueType  # 0
        METHOD_GET: CorsRule._Method.ValueType  # 1
        """HTTP `GET` method."""
        METHOD_HEAD: CorsRule._Method.ValueType  # 2
        """HTTP `HEAD` method."""
        METHOD_POST: CorsRule._Method.ValueType  # 3
        """HTTP `POST` method."""
        METHOD_PUT: CorsRule._Method.ValueType  # 4
        """HTTP `PUT` method."""
        METHOD_DELETE: CorsRule._Method.ValueType  # 5
        """HTTP `DELETE` method."""

    class Method(_Method, metaclass=_MethodEnumTypeWrapper):
        """List of HTTP methods that are allowed by the CORS rule.

        When a client sends a CORS-preflight `options` request with the `Access-Control-Request-Method` header (see
        S3-compatible API reference](/docs/storage/s3/api-ref/object/options)), the specified method is checked against the
        list of the allowed methods. If there is a match, all the allowed methods are listed in the
        `Access-Control-Allow-Methods` header of the response.
        """

    METHOD_UNSPECIFIED: CorsRule.Method.ValueType  # 0
    METHOD_GET: CorsRule.Method.ValueType  # 1
    """HTTP `GET` method."""
    METHOD_HEAD: CorsRule.Method.ValueType  # 2
    """HTTP `HEAD` method."""
    METHOD_POST: CorsRule.Method.ValueType  # 3
    """HTTP `POST` method."""
    METHOD_PUT: CorsRule.Method.ValueType  # 4
    """HTTP `PUT` method."""
    METHOD_DELETE: CorsRule.Method.ValueType  # 5
    """HTTP `DELETE` method."""

    ID_FIELD_NUMBER: builtins.int
    ALLOWED_METHODS_FIELD_NUMBER: builtins.int
    ALLOWED_HEADERS_FIELD_NUMBER: builtins.int
    ALLOWED_ORIGINS_FIELD_NUMBER: builtins.int
    EXPOSE_HEADERS_FIELD_NUMBER: builtins.int
    MAX_AGE_SECONDS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the CORS rule."""
    @property
    def allowed_methods(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___CorsRule.Method.ValueType]:
        """List of HTTP methods allowed by the CORS rule.

        When a client sends a CORS-preflight `options` request with the `Access-Control-Request-Method` header (see
        [S3-compatible API reference](/docs/storage/s3/api-ref/object/options)), the specified method is checked against
        the list of the allowed methods. If there is a match, all the allowed methods are listed in the
        `Access-Control-Allow-Methods` header of the response.
        """

    @property
    def allowed_headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of HTTP headers allowed by the CORS rule.

        When a client sends a CORS-preflight `options` request with the `Access-Control-Request-Headers` header (see
        [S3-compatible API reference](/docs/storage/s3/api-ref/object/options)), the specified headers are checked against
        the list of the allowed headers. If there is a match, the specified headers that are allowed are listed in the
        `Access-Control-Allow-Headers` header of the response.

        Each string in the list can contain at most one `*` wildcard character that matches 0 or more characters.
        For example, `x-amz-*` value will allow all Amazon S3-compatible headers.
        """

    @property
    def allowed_origins(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of request origins allowed by the CORS rule.

        Each string in the list can contain at most one `*` wildcard character that matches 0 or more characters.
        For example, `http://*.example.com` value will allow requests originating from all subdomains of `example.com`.
        """

    @property
    def expose_headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of headers contained in responses to CORS requests that can be accessed by applications."""

    @property
    def max_age_seconds(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Time in seconds that a client can cache the response to a CORS-preflight request as identified by the
        object requested, the HTTP method, and the origin.
        """

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        allowed_methods: collections.abc.Iterable[global___CorsRule.Method.ValueType] | None = ...,
        allowed_headers: collections.abc.Iterable[builtins.str] | None = ...,
        allowed_origins: collections.abc.Iterable[builtins.str] | None = ...,
        expose_headers: collections.abc.Iterable[builtins.str] | None = ...,
        max_age_seconds: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["max_age_seconds", b"max_age_seconds"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["allowed_headers", b"allowed_headers", "allowed_methods", b"allowed_methods", "allowed_origins", b"allowed_origins", "expose_headers", b"expose_headers", "id", b"id", "max_age_seconds", b"max_age_seconds"]) -> None: ...

global___CorsRule = CorsRule

@typing.final
class WebsiteSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Protocol:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ProtocolEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[WebsiteSettings._Protocol.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PROTOCOL_UNSPECIFIED: WebsiteSettings._Protocol.ValueType  # 0
        PROTOCOL_HTTP: WebsiteSettings._Protocol.ValueType  # 1
        """`http` scheme."""
        PROTOCOL_HTTPS: WebsiteSettings._Protocol.ValueType  # 2
        """`https` scheme."""

    class Protocol(_Protocol, metaclass=_ProtocolEnumTypeWrapper): ...
    PROTOCOL_UNSPECIFIED: WebsiteSettings.Protocol.ValueType  # 0
    PROTOCOL_HTTP: WebsiteSettings.Protocol.ValueType  # 1
    """`http` scheme."""
    PROTOCOL_HTTPS: WebsiteSettings.Protocol.ValueType  # 2
    """`https` scheme."""

    @typing.final
    class Scheme(google.protobuf.message.Message):
        """A configuration resource for redirecting all requests sent to the website."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        PROTOCOL_FIELD_NUMBER: builtins.int
        HOSTNAME_FIELD_NUMBER: builtins.int
        protocol: global___WebsiteSettings.Protocol.ValueType
        """Scheme of the redirect URI."""
        hostname: builtins.str
        """Hostname of the redirect URI."""
        def __init__(
            self,
            *,
            protocol: global___WebsiteSettings.Protocol.ValueType = ...,
            hostname: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["hostname", b"hostname", "protocol", b"protocol"]) -> None: ...

    @typing.final
    class Condition(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        HTTP_ERROR_CODE_RETURNED_EQUALS_FIELD_NUMBER: builtins.int
        KEY_PREFIX_EQUALS_FIELD_NUMBER: builtins.int
        http_error_code_returned_equals: builtins.str
        """HTTP status code (number only) that must match for the redirect to apply."""
        key_prefix_equals: builtins.str
        """Prefix of the object key from which requests are redirected."""
        def __init__(
            self,
            *,
            http_error_code_returned_equals: builtins.str = ...,
            key_prefix_equals: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["http_error_code_returned_equals", b"http_error_code_returned_equals", "key_prefix_equals", b"key_prefix_equals"]) -> None: ...

    @typing.final
    class Redirect(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        HOSTNAME_FIELD_NUMBER: builtins.int
        HTTP_REDIRECT_CODE_FIELD_NUMBER: builtins.int
        PROTOCOL_FIELD_NUMBER: builtins.int
        REPLACE_KEY_PREFIX_WITH_FIELD_NUMBER: builtins.int
        REPLACE_KEY_WITH_FIELD_NUMBER: builtins.int
        hostname: builtins.str
        """Hostname of the redirect URI."""
        http_redirect_code: builtins.str
        """HTTP status code of the redirect response.

        Default value: `"301"`.
        """
        protocol: global___WebsiteSettings.Protocol.ValueType
        """Scheme of the redirect URI."""
        replace_key_prefix_with: builtins.str
        """Substitution for the prefix of the object key specified in [Condition.key_prefix_equals].

        At most one of [replace_key_prefix_with] and [replace_key_with] can be specified.
        """
        replace_key_with: builtins.str
        """New object key.

        At most one of [replace_key_with] and [replace_key_prefix_with] can be specified.
        """
        def __init__(
            self,
            *,
            hostname: builtins.str = ...,
            http_redirect_code: builtins.str = ...,
            protocol: global___WebsiteSettings.Protocol.ValueType = ...,
            replace_key_prefix_with: builtins.str = ...,
            replace_key_with: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["hostname", b"hostname", "http_redirect_code", b"http_redirect_code", "protocol", b"protocol", "replace_key_prefix_with", b"replace_key_prefix_with", "replace_key_with", b"replace_key_with"]) -> None: ...

    @typing.final
    class RoutingRule(google.protobuf.message.Message):
        """List of redirect rules."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CONDITION_FIELD_NUMBER: builtins.int
        REDIRECT_FIELD_NUMBER: builtins.int
        @property
        def condition(self) -> global___WebsiteSettings.Condition:
            """Redirect condition."""

        @property
        def redirect(self) -> global___WebsiteSettings.Redirect:
            """Redirect instructions."""

        def __init__(
            self,
            *,
            condition: global___WebsiteSettings.Condition | None = ...,
            redirect: global___WebsiteSettings.Redirect | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["condition", b"condition", "redirect", b"redirect"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["condition", b"condition", "redirect", b"redirect"]) -> None: ...

    INDEX_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    REDIRECT_ALL_REQUESTS_FIELD_NUMBER: builtins.int
    ROUTING_RULES_FIELD_NUMBER: builtins.int
    index: builtins.str
    """Key of the index page object that is returned when a response is made to the root of the website.

    Either [index] or [redirect_all_requests] must be specified in order for the bucket to host a static website.

    If specified, the index page object must be located in the root of the bucket.
    """
    error: builtins.str
    """Key of the error page object that is returned when an error occurs."""
    @property
    def redirect_all_requests(self) -> global___WebsiteSettings.Scheme:
        """Configuration for redirecting all requests sent to the website.

        Either [redirect_all_requests] or [index] must be specified in order for the bucket to host a static website.
        If [redirect_all_requests] is specified, it must be the only field in [Bucket.website_settings].
        """

    @property
    def routing_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WebsiteSettings.RoutingRule]:
        """List of redirect rules."""

    def __init__(
        self,
        *,
        index: builtins.str = ...,
        error: builtins.str = ...,
        redirect_all_requests: global___WebsiteSettings.Scheme | None = ...,
        routing_rules: collections.abc.Iterable[global___WebsiteSettings.RoutingRule] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["redirect_all_requests", b"redirect_all_requests"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["error", b"error", "index", b"index", "redirect_all_requests", b"redirect_all_requests", "routing_rules", b"routing_rules"]) -> None: ...

global___WebsiteSettings = WebsiteSettings

@typing.final
class LifecycleRule(google.protobuf.message.Message):
    """An object lifecycle rule resource for the bucket.
    For details about the concept, see [documentation](/docs/storage/concepts/lifecycles).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class AfterDays(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        DAYS_AFTER_EXPIRATION_FIELD_NUMBER: builtins.int
        @property
        def days_after_expiration(self) -> google.protobuf.wrappers_pb2.Int64Value:
            """Time period, in number of days from the start of the multipart upload, after which the incomplete upload is
            aborted.
            """

        def __init__(
            self,
            *,
            days_after_expiration: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["days_after_expiration", b"days_after_expiration"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["days_after_expiration", b"days_after_expiration"]) -> None: ...

    @typing.final
    class NoncurrentDeleteMarkers(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NONCURRENT_DAYS_FIELD_NUMBER: builtins.int
        @property
        def noncurrent_days(self) -> google.protobuf.wrappers_pb2.Int64Value:
            """Time period, in number of days since the version of a delete marker was classified as non-current, after which
            the delete marker expires.
            """

        def __init__(
            self,
            *,
            noncurrent_days: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["noncurrent_days", b"noncurrent_days"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["noncurrent_days", b"noncurrent_days"]) -> None: ...

    @typing.final
    class NoncurrentExpiration(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NONCURRENT_DAYS_FIELD_NUMBER: builtins.int
        @property
        def noncurrent_days(self) -> google.protobuf.wrappers_pb2.Int64Value:
            """Time period, in number of days since the version of an object was classified as non-current, after which the
            version expires.
            """

        def __init__(
            self,
            *,
            noncurrent_days: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["noncurrent_days", b"noncurrent_days"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["noncurrent_days", b"noncurrent_days"]) -> None: ...

    @typing.final
    class NoncurrentTransition(google.protobuf.message.Message):
        """List of transition rules for non-current versions of objects in a bucket with versioning enabled
        ([Bucket.versioning] is `VERSIONING_ENABLED`) or suspended (`VERSIONING_SUSPENDED`).

        At transition, the non-current version of the object is transitioned to the specified storage class.
        """

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NONCURRENT_DAYS_FIELD_NUMBER: builtins.int
        STORAGE_CLASS_FIELD_NUMBER: builtins.int
        storage_class: builtins.str
        """Storage class to which a non-current version of an object is transitioned from standard storage.

        The only supported class is cold storage (`COLD`, `STANDARD_IA`, `NEARLINE` all synonyms). Transitions from cold
        to standard storage and transitions to or from ice storage are not allowed.
        """
        @property
        def noncurrent_days(self) -> google.protobuf.wrappers_pb2.Int64Value:
            """Time period, in number of days since the version of an object was classified as non-current, after which the
            version is transitioned.
            """

        def __init__(
            self,
            *,
            noncurrent_days: google.protobuf.wrappers_pb2.Int64Value | None = ...,
            storage_class: builtins.str = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["noncurrent_days", b"noncurrent_days"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["noncurrent_days", b"noncurrent_days", "storage_class", b"storage_class"]) -> None: ...

    @typing.final
    class Transition(google.protobuf.message.Message):
        """List of transition rules.

        The transition of an object is described as follows.

        For the unversioned bucket ([Bucket.versioning] is `VERSIONING_DISABLED`), the object is transitioned to the
        specified storage class.

        For the bucket with versioning enabled ([Bucket.versioning] is `VERSIONING_ENABLED`) or suspended
        (`VERSIONING_SUSPENDED`), the current version of the object is transitioned to the specified storage class.
        """

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        DATE_FIELD_NUMBER: builtins.int
        DAYS_FIELD_NUMBER: builtins.int
        STORAGE_CLASS_FIELD_NUMBER: builtins.int
        storage_class: builtins.str
        """Storage class to which an object is transitioned from standard storage.

        The only supported class is cold storage (`COLD`, `STANDARD_IA`, `NEARLINE` all synonyms). Transitions from cold
        to standard storage and transitions to or from ice storage are not allowed.
        """
        @property
        def date(self) -> google.protobuf.timestamp_pb2.Timestamp:
            """Specific date of object transition.

            The rule continues to apply even after the date has passed, i.e. any new objects created in the bucket are
            transitioned immediately.

            At most one of [date] and [days] fields can be specified.
            """

        @property
        def days(self) -> google.protobuf.wrappers_pb2.Int64Value:
            """Time period, in number of days from the creation or modification of the object, after which an object is
            transitioned.

            At most one of [days] and [date] fields can be specified.
            """

        def __init__(
            self,
            *,
            date: google.protobuf.timestamp_pb2.Timestamp | None = ...,
            days: google.protobuf.wrappers_pb2.Int64Value | None = ...,
            storage_class: builtins.str = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["date", b"date", "days", b"days"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["date", b"date", "days", b"days", "storage_class", b"storage_class"]) -> None: ...

    @typing.final
    class Expiration(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        DATE_FIELD_NUMBER: builtins.int
        DAYS_FIELD_NUMBER: builtins.int
        EXPIRED_OBJECT_DELETE_MARKER_FIELD_NUMBER: builtins.int
        @property
        def date(self) -> google.protobuf.timestamp_pb2.Timestamp:
            """Specific date of object expiration.

            The rule continues to apply even after the date has passed, i.e. any new objects created in the bucket expire
            immediately.

            Exactly one of [date], [days], and [expired_object_delete_marker] fields can be specified.
            """

        @property
        def days(self) -> google.protobuf.wrappers_pb2.Int64Value:
            """Time period, in number of days from the creation or modification of the object, after which an object expires.

            Exactly one of [days], [date], and [expired_object_delete_marker] fields can be specified.
            """

        @property
        def expired_object_delete_marker(self) -> google.protobuf.wrappers_pb2.BoolValue:
            """Indicates whether a delete marker of an object with no non-current versions (referred to as an expired object
            delete marker) is removed at the object's expiration.

            Exactly one of [expired_object_delete_marker], [date], and [days] fields can be specified.
            """

        def __init__(
            self,
            *,
            date: google.protobuf.timestamp_pb2.Timestamp | None = ...,
            days: google.protobuf.wrappers_pb2.Int64Value | None = ...,
            expired_object_delete_marker: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["date", b"date", "days", b"days", "expired_object_delete_marker", b"expired_object_delete_marker"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["date", b"date", "days", b"days", "expired_object_delete_marker", b"expired_object_delete_marker"]) -> None: ...

    @typing.final
    class RuleFilter(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class And(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            PREFIX_FIELD_NUMBER: builtins.int
            OBJECT_SIZE_GREATER_THAN_FIELD_NUMBER: builtins.int
            OBJECT_SIZE_LESS_THAN_FIELD_NUMBER: builtins.int
            TAG_FIELD_NUMBER: builtins.int
            prefix: builtins.str
            @property
            def object_size_greater_than(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
            @property
            def object_size_less_than(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
            @property
            def tag(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Tag]: ...
            def __init__(
                self,
                *,
                prefix: builtins.str = ...,
                object_size_greater_than: google.protobuf.wrappers_pb2.Int64Value | None = ...,
                object_size_less_than: google.protobuf.wrappers_pb2.Int64Value | None = ...,
                tag: collections.abc.Iterable[global___Tag] | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["object_size_greater_than", b"object_size_greater_than", "object_size_less_than", b"object_size_less_than"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["object_size_greater_than", b"object_size_greater_than", "object_size_less_than", b"object_size_less_than", "prefix", b"prefix", "tag", b"tag"]) -> None: ...

        PREFIX_FIELD_NUMBER: builtins.int
        OBJECT_SIZE_GREATER_THAN_FIELD_NUMBER: builtins.int
        OBJECT_SIZE_LESS_THAN_FIELD_NUMBER: builtins.int
        TAG_FIELD_NUMBER: builtins.int
        AND_OPERATOR_FIELD_NUMBER: builtins.int
        prefix: builtins.str
        """Key prefix that the object must have in order for the rule to apply."""
        @property
        def object_size_greater_than(self) -> google.protobuf.wrappers_pb2.Int64Value:
            """Size that the object must be greater."""

        @property
        def object_size_less_than(self) -> google.protobuf.wrappers_pb2.Int64Value:
            """Size that the object must be less t."""

        @property
        def tag(self) -> global___Tag:
            """Tags that the object's tag set must have for the rule to apply."""

        @property
        def and_operator(self) -> global___LifecycleRule.RuleFilter.And:
            """Apply a logical AND to all of the predicates configured inside the And operator."""

        def __init__(
            self,
            *,
            prefix: builtins.str = ...,
            object_size_greater_than: google.protobuf.wrappers_pb2.Int64Value | None = ...,
            object_size_less_than: google.protobuf.wrappers_pb2.Int64Value | None = ...,
            tag: global___Tag | None = ...,
            and_operator: global___LifecycleRule.RuleFilter.And | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["and_operator", b"and_operator", "object_size_greater_than", b"object_size_greater_than", "object_size_less_than", b"object_size_less_than", "tag", b"tag"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["and_operator", b"and_operator", "object_size_greater_than", b"object_size_greater_than", "object_size_less_than", b"object_size_less_than", "prefix", b"prefix", "tag", b"tag"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    EXPIRATION_FIELD_NUMBER: builtins.int
    TRANSITIONS_FIELD_NUMBER: builtins.int
    ABORT_INCOMPLETE_MULTIPART_UPLOAD_FIELD_NUMBER: builtins.int
    NONCURRENT_EXPIRATION_FIELD_NUMBER: builtins.int
    NONCURRENT_TRANSITIONS_FIELD_NUMBER: builtins.int
    NONCURRENT_DELETE_MARKERS_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    """Indicates whether the rule is in effect."""
    @property
    def id(self) -> google.protobuf.wrappers_pb2.StringValue:
        """ID of the rule. Provided by the client or generated at creation time."""

    @property
    def filter(self) -> global___LifecycleRule.RuleFilter:
        """Filter that identifies the objects to which the rule applies.

        If not specified, the rule applies to all objects in the bucket.
        """

    @property
    def expiration(self) -> global___LifecycleRule.Expiration:
        """Expiration rule.

        The expiration of an object is described as follows.

        For the unversioned bucket ([Bucket.versioning] is `VERSIONING_DISABLED`), the object is deleted and cannot be
        recovered.

        For the bucket with versioning enabled ([Bucket.versioning] is `VERSIONING_ENABLED`), the current version of the
        object (if it exists and is not a delete marker) is retained as a non-current version, and a delete marker becomes
        the current version of the object.

        For the bucket with versioning suspended ([Bucket.versioning] is `VERSIONING_SUSPENDED`), the current version of
        the object is retained as a non-current version if it is not a delete marker, or is removed otherwise, and a
        delete marker becomes the current version of the object.
        """

    @property
    def transitions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LifecycleRule.Transition]:
        """List of transition rules.

        The transition of an object is described as follows.

        For the unversioned bucket ([Bucket.versioning] is `VERSIONING_DISABLED`), the object is transitioned to the
        specified storage class.

        For the bucket with versioning enabled ([Bucket.versioning] is `VERSIONING_ENABLED`) or suspended
        (`VERSIONING_SUSPENDED`), the current version of the object is transitioned to the specified storage class.
        """

    @property
    def abort_incomplete_multipart_upload(self) -> global___LifecycleRule.AfterDays:
        """Configuration for aborting incomplete [multipart uploads](/docs/storage/concepts/multipart)."""

    @property
    def noncurrent_expiration(self) -> global___LifecycleRule.NoncurrentExpiration:
        """Expiration rule for non-current versions of objects in a bucket with versioning enabled ([Bucket.versioning] is
        `VERSIONING_ENABLED`) or suspended (`VERSIONING_SUSPENDED`).

        At expiration, the non-current version of the object is deleted and cannot be recovered.
        """

    @property
    def noncurrent_transitions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LifecycleRule.NoncurrentTransition]:
        """List of transition rules for non-current versions of objects in a bucket with versioning enabled
        ([Bucket.versioning] is `VERSIONING_ENABLED`) or suspended (`VERSIONING_SUSPENDED`).

        At transition, the non-current version of the object is transitioned to the specified storage class.
        """

    @property
    def noncurrent_delete_markers(self) -> global___LifecycleRule.NoncurrentDeleteMarkers:
        """Expiration rule for non-current delete markers of an objects in a bucket with versioning
        enabled ([Bucket.versioning] is `VERSIONING_ENABLED`) or suspended (`VERSIONING_SUSPENDED`).
        Works in the same way as noncurrent_expiration rule, but only for delete markers.

        At expiration, the non-current delete marker of the object is deleted and cannot be recovered.
        """

    def __init__(
        self,
        *,
        id: google.protobuf.wrappers_pb2.StringValue | None = ...,
        enabled: builtins.bool = ...,
        filter: global___LifecycleRule.RuleFilter | None = ...,
        expiration: global___LifecycleRule.Expiration | None = ...,
        transitions: collections.abc.Iterable[global___LifecycleRule.Transition] | None = ...,
        abort_incomplete_multipart_upload: global___LifecycleRule.AfterDays | None = ...,
        noncurrent_expiration: global___LifecycleRule.NoncurrentExpiration | None = ...,
        noncurrent_transitions: collections.abc.Iterable[global___LifecycleRule.NoncurrentTransition] | None = ...,
        noncurrent_delete_markers: global___LifecycleRule.NoncurrentDeleteMarkers | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["abort_incomplete_multipart_upload", b"abort_incomplete_multipart_upload", "expiration", b"expiration", "filter", b"filter", "id", b"id", "noncurrent_delete_markers", b"noncurrent_delete_markers", "noncurrent_expiration", b"noncurrent_expiration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["abort_incomplete_multipart_upload", b"abort_incomplete_multipart_upload", "enabled", b"enabled", "expiration", b"expiration", "filter", b"filter", "id", b"id", "noncurrent_delete_markers", b"noncurrent_delete_markers", "noncurrent_expiration", b"noncurrent_expiration", "noncurrent_transitions", b"noncurrent_transitions", "transitions", b"transitions"]) -> None: ...

global___LifecycleRule = LifecycleRule

@typing.final
class Counters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIMPLE_OBJECT_SIZE_FIELD_NUMBER: builtins.int
    SIMPLE_OBJECT_COUNT_FIELD_NUMBER: builtins.int
    OBJECTS_PARTS_SIZE_FIELD_NUMBER: builtins.int
    OBJECTS_PARTS_COUNT_FIELD_NUMBER: builtins.int
    MULTIPART_OBJECTS_SIZE_FIELD_NUMBER: builtins.int
    MULTIPART_OBJECTS_COUNT_FIELD_NUMBER: builtins.int
    ACTIVE_MULTIPART_COUNT_FIELD_NUMBER: builtins.int
    simple_object_size: builtins.int
    """Total size of objects uploaded in single operation, in bytes."""
    simple_object_count: builtins.int
    """Number of objects uploaded in single operation."""
    objects_parts_size: builtins.int
    """Total size of uploaded parts in incomplete multipart uploads, in bytes."""
    objects_parts_count: builtins.int
    """Number of uploaded parts in incomplete multipart uploads."""
    multipart_objects_size: builtins.int
    """Total size of objects uploaded in multiple parts, in bytes."""
    multipart_objects_count: builtins.int
    """Number of objects uploaded in multiple parts."""
    active_multipart_count: builtins.int
    """Number of incomplete multipart uploads."""
    def __init__(
        self,
        *,
        simple_object_size: builtins.int = ...,
        simple_object_count: builtins.int = ...,
        objects_parts_size: builtins.int = ...,
        objects_parts_count: builtins.int = ...,
        multipart_objects_size: builtins.int = ...,
        multipart_objects_count: builtins.int = ...,
        active_multipart_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["active_multipart_count", b"active_multipart_count", "multipart_objects_count", b"multipart_objects_count", "multipart_objects_size", b"multipart_objects_size", "objects_parts_count", b"objects_parts_count", "objects_parts_size", b"objects_parts_size", "simple_object_count", b"simple_object_count", "simple_object_size", b"simple_object_size"]) -> None: ...

global___Counters = Counters

@typing.final
class OptionalSizeByClass(google.protobuf.message.Message):
    """A resource for size of available space in a bucket for a storage class."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STORAGE_CLASS_FIELD_NUMBER: builtins.int
    CLASS_SIZE_FIELD_NUMBER: builtins.int
    storage_class: builtins.str
    """Storage class. Supported classes are standard storage (`STANDARD`), cold storage (`COLD`, `STANDARD_IA`, `NEARLINE`
    all synonyms), and ice storage (`ICE` and `GLACIER` are synonyms).
    For details, see [documentation](/docs/storage/concepts/storage-class).
    """
    @property
    def class_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Size of available space in the bucket for the storage class."""

    def __init__(
        self,
        *,
        storage_class: builtins.str = ...,
        class_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["class_size", b"class_size"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["class_size", b"class_size", "storage_class", b"storage_class"]) -> None: ...

global___OptionalSizeByClass = OptionalSizeByClass

@typing.final
class SizeByClass(google.protobuf.message.Message):
    """A resource for size of used space in a bucket for a storage class."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STORAGE_CLASS_FIELD_NUMBER: builtins.int
    CLASS_SIZE_FIELD_NUMBER: builtins.int
    storage_class: builtins.str
    """Storage class. Supported classes are standard storage (`STANDARD`), cold storage (`COLD`, `STANDARD_IA`, `NEARLINE`
    all synonyms), and ice storage (`ICE` and `GLACIER` are synonyms).
    For details, see [documentation](/docs/storage/concepts/storage-class).
    """
    class_size: builtins.int
    """Size of used space in the bucket for the storage class."""
    def __init__(
        self,
        *,
        storage_class: builtins.str = ...,
        class_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["class_size", b"class_size", "storage_class", b"storage_class"]) -> None: ...

global___SizeByClass = SizeByClass

@typing.final
class CountersByClass(google.protobuf.message.Message):
    """A resource for object-related statistics for a storage class by type of upload (simple vs. multipart)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STORAGE_CLASS_FIELD_NUMBER: builtins.int
    COUNTERS_FIELD_NUMBER: builtins.int
    storage_class: builtins.str
    """Storage class. Supported classes are standard storage (`STANDARD`), cold storage (`COLD`, `STANDARD_IA`, `NEARLINE`
    all synonyms), and ice storage (`ice` and `GLACIER` are synonyms).
    For details, see [documentation](/docs/storage/concepts/storage-class).
    """
    @property
    def counters(self) -> global___Counters:
        """Object-related statistics for the storage class by type of upload."""

    def __init__(
        self,
        *,
        storage_class: builtins.str = ...,
        counters: global___Counters | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["counters", b"counters"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["counters", b"counters", "storage_class", b"storage_class"]) -> None: ...

global___CountersByClass = CountersByClass

@typing.final
class BucketStats(google.protobuf.message.Message):
    """A bucket statistics resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    MAX_SIZE_FIELD_NUMBER: builtins.int
    USED_SIZE_FIELD_NUMBER: builtins.int
    STORAGE_CLASS_MAX_SIZES_FIELD_NUMBER: builtins.int
    STORAGE_CLASS_USED_SIZES_FIELD_NUMBER: builtins.int
    STORAGE_CLASS_COUNTERS_FIELD_NUMBER: builtins.int
    DEFAULT_STORAGE_CLASS_FIELD_NUMBER: builtins.int
    ANONYMOUS_ACCESS_FLAGS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the bucket."""
    used_size: builtins.int
    """Size of used space in the bucket, in bytes."""
    @property
    def max_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum size of the bucket, in bytes."""

    @property
    def storage_class_max_sizes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OptionalSizeByClass]:
        """Size of available space in the bucket by storage class, in bytes."""

    @property
    def storage_class_used_sizes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SizeByClass]:
        """Size of used space in the bucket by storage class, in bytes."""

    @property
    def storage_class_counters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CountersByClass]:
        """Object-related statistics by storage class and type of upload (simple vs. multipart), in bytes."""

    @property
    def default_storage_class(self) -> google.protobuf.wrappers_pb2.StringValue:
        """Default storage class for objects in the bucket. Supported classes are standard storage (`STANDARD`), cold storage
        (`COLD`, `STANDARD_IA`, `NEARLINE` all synonyms), and ice storage (`ICE` and `GLACIER` are synonyms).
        For details, see [documentation](/docs/storage/concepts/storage-class).
        """

    @property
    def anonymous_access_flags(self) -> global___AnonymousAccessFlags:
        """Flags for configuring public (anonymous) access to the bucket's content and settings.
        For details, see [documentation](/docs/storage/concepts/bucket#bucket-access).
        """

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Bucket creation timestamp."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Bucket latest update timestamp."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        max_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        used_size: builtins.int = ...,
        storage_class_max_sizes: collections.abc.Iterable[global___OptionalSizeByClass] | None = ...,
        storage_class_used_sizes: collections.abc.Iterable[global___SizeByClass] | None = ...,
        storage_class_counters: collections.abc.Iterable[global___CountersByClass] | None = ...,
        default_storage_class: google.protobuf.wrappers_pb2.StringValue | None = ...,
        anonymous_access_flags: global___AnonymousAccessFlags | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["anonymous_access_flags", b"anonymous_access_flags", "created_at", b"created_at", "default_storage_class", b"default_storage_class", "max_size", b"max_size", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["anonymous_access_flags", b"anonymous_access_flags", "created_at", b"created_at", "default_storage_class", b"default_storage_class", "max_size", b"max_size", "name", b"name", "storage_class_counters", b"storage_class_counters", "storage_class_max_sizes", b"storage_class_max_sizes", "storage_class_used_sizes", b"storage_class_used_sizes", "updated_at", b"updated_at", "used_size", b"used_size"]) -> None: ...

global___BucketStats = BucketStats

@typing.final
class HTTPSConfig(google.protobuf.message.Message):
    """A resource for HTTPS configuration of a bucket."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _SourceType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _SourceTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[HTTPSConfig._SourceType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SOURCE_TYPE_UNSPECIFIED: HTTPSConfig._SourceType.ValueType  # 0
        SOURCE_TYPE_SELF_MANAGED: HTTPSConfig._SourceType.ValueType  # 1
        """Your certificate, uploaded directly."""
        SOURCE_TYPE_MANAGED_BY_CERTIFICATE_MANAGER: HTTPSConfig._SourceType.ValueType  # 2
        """Certificate managed by Certificate Manager."""

    class SourceType(_SourceType, metaclass=_SourceTypeEnumTypeWrapper):
        """A resource for type of TLS certificate source."""

    SOURCE_TYPE_UNSPECIFIED: HTTPSConfig.SourceType.ValueType  # 0
    SOURCE_TYPE_SELF_MANAGED: HTTPSConfig.SourceType.ValueType  # 1
    """Your certificate, uploaded directly."""
    SOURCE_TYPE_MANAGED_BY_CERTIFICATE_MANAGER: HTTPSConfig.SourceType.ValueType  # 2
    """Certificate managed by Certificate Manager."""

    NAME_FIELD_NUMBER: builtins.int
    SOURCE_TYPE_FIELD_NUMBER: builtins.int
    ISSUER_FIELD_NUMBER: builtins.int
    SUBJECT_FIELD_NUMBER: builtins.int
    DNS_NAMES_FIELD_NUMBER: builtins.int
    NOT_BEFORE_FIELD_NUMBER: builtins.int
    NOT_AFTER_FIELD_NUMBER: builtins.int
    CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the bucket."""
    source_type: global___HTTPSConfig.SourceType.ValueType
    """Type of TLS certificate source."""
    certificate_id: builtins.str
    """ID of the TLS certificate in Certificate Manager.

    To get information about the certificate from Certificate Manager, make a
    [yandex.cloud.certificatemanager.v1.CertificateService.Get] request.
    """
    @property
    def issuer(self) -> google.protobuf.wrappers_pb2.StringValue:
        """Issuer of the TLS certificate."""

    @property
    def subject(self) -> google.protobuf.wrappers_pb2.StringValue:
        """Subject of the TLS certificate."""

    @property
    def dns_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of DNS names of the TLS certificate (Subject Alternative Name field)."""

    @property
    def not_before(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Start of the TLS certificate validity period (Not Before field)."""

    @property
    def not_after(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """End of the TLS certificate validity period (Not After field)"""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        source_type: global___HTTPSConfig.SourceType.ValueType = ...,
        issuer: google.protobuf.wrappers_pb2.StringValue | None = ...,
        subject: google.protobuf.wrappers_pb2.StringValue | None = ...,
        dns_names: collections.abc.Iterable[builtins.str] | None = ...,
        not_before: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        not_after: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        certificate_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["issuer", b"issuer", "not_after", b"not_after", "not_before", b"not_before", "subject", b"subject"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["certificate_id", b"certificate_id", "dns_names", b"dns_names", "issuer", b"issuer", "name", b"name", "not_after", b"not_after", "not_before", b"not_before", "source_type", b"source_type", "subject", b"subject"]) -> None: ...

global___HTTPSConfig = HTTPSConfig

@typing.final
class ObjectLock(google.protobuf.message.Message):
    """A resource for Object Lock configuration of a bucket.
    For details about the concept, see [documentation](/docs/storage/concepts/object-lock).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ObjectLockStatus:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ObjectLockStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ObjectLock._ObjectLockStatus.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        OBJECT_LOCK_STATUS_UNSPECIFIED: ObjectLock._ObjectLockStatus.ValueType  # 0
        OBJECT_LOCK_STATUS_DISABLED: ObjectLock._ObjectLockStatus.ValueType  # 1
        OBJECT_LOCK_STATUS_ENABLED: ObjectLock._ObjectLockStatus.ValueType  # 2

    class ObjectLockStatus(_ObjectLockStatus, metaclass=_ObjectLockStatusEnumTypeWrapper):
        """Activity status of the object lock settings on the bucket"""

    OBJECT_LOCK_STATUS_UNSPECIFIED: ObjectLock.ObjectLockStatus.ValueType  # 0
    OBJECT_LOCK_STATUS_DISABLED: ObjectLock.ObjectLockStatus.ValueType  # 1
    OBJECT_LOCK_STATUS_ENABLED: ObjectLock.ObjectLockStatus.ValueType  # 2

    @typing.final
    class DefaultRetention(google.protobuf.message.Message):
        """Default lock configuration for added objects"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Mode:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _ModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ObjectLock.DefaultRetention._Mode.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            MODE_UNSPECIFIED: ObjectLock.DefaultRetention._Mode.ValueType  # 0
            MODE_GOVERNANCE: ObjectLock.DefaultRetention._Mode.ValueType  # 1
            MODE_COMPLIANCE: ObjectLock.DefaultRetention._Mode.ValueType  # 2

        class Mode(_Mode, metaclass=_ModeEnumTypeWrapper):
            """Lock type"""

        MODE_UNSPECIFIED: ObjectLock.DefaultRetention.Mode.ValueType  # 0
        MODE_GOVERNANCE: ObjectLock.DefaultRetention.Mode.ValueType  # 1
        MODE_COMPLIANCE: ObjectLock.DefaultRetention.Mode.ValueType  # 2

        MODE_FIELD_NUMBER: builtins.int
        DAYS_FIELD_NUMBER: builtins.int
        YEARS_FIELD_NUMBER: builtins.int
        mode: global___ObjectLock.DefaultRetention.Mode.ValueType
        days: builtins.int
        """Number of days for locking"""
        years: builtins.int
        """Number of years for locking"""
        def __init__(
            self,
            *,
            mode: global___ObjectLock.DefaultRetention.Mode.ValueType = ...,
            days: builtins.int = ...,
            years: builtins.int = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["days", b"days", "period", b"period", "years", b"years"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["days", b"days", "mode", b"mode", "period", b"period", "years", b"years"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["period", b"period"]) -> typing.Literal["days", "years"] | None: ...

    STATUS_FIELD_NUMBER: builtins.int
    DEFAULT_RETENTION_FIELD_NUMBER: builtins.int
    status: global___ObjectLock.ObjectLockStatus.ValueType
    @property
    def default_retention(self) -> global___ObjectLock.DefaultRetention: ...
    def __init__(
        self,
        *,
        status: global___ObjectLock.ObjectLockStatus.ValueType = ...,
        default_retention: global___ObjectLock.DefaultRetention | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["default_retention", b"default_retention"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_retention", b"default_retention", "status", b"status"]) -> None: ...

global___ObjectLock = ObjectLock

@typing.final
class Encryption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class EncryptionRule(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KMS_MASTER_KEY_ID_FIELD_NUMBER: builtins.int
        SSE_ALGORITHM_FIELD_NUMBER: builtins.int
        kms_master_key_id: builtins.str
        sse_algorithm: builtins.str
        def __init__(
            self,
            *,
            kms_master_key_id: builtins.str = ...,
            sse_algorithm: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["kms_master_key_id", b"kms_master_key_id", "sse_algorithm", b"sse_algorithm"]) -> None: ...

    RULES_FIELD_NUMBER: builtins.int
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Encryption.EncryptionRule]: ...
    def __init__(
        self,
        *,
        rules: collections.abc.Iterable[global___Encryption.EncryptionRule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["rules", b"rules"]) -> None: ...

global___Encryption = Encryption



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/iam/v1/iam_token_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+yandex/cloud/iam/v1/iam_token_service.proto\x12\x13yandex.cloud.iam.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"_\n\x15\x43reateIamTokenRequest\x12%\n\x1byandex_passport_oauth_token\x18\x01 \x01(\tH\x00\x12\r\n\x03jwt\x18\x02 \x01(\tH\x00\x42\x10\n\x08identity\x12\x04\xc0\xc1\x31\x01\"[\n\x16\x43reateIamTokenResponse\x12\x11\n\tiam_token\x18\x01 \x01(\t\x12.\n\nexpires_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"R\n&CreateIamTokenForServiceAccountRequest\x12(\n\x12service_account_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=502\xc8\x02\n\x0fIamTokenService\x12|\n\x06\x43reate\x12*.yandex.cloud.iam.v1.CreateIamTokenRequest\x1a+.yandex.cloud.iam.v1.CreateIamTokenResponse\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/iam/v1/tokens:\x01*\x12\xb6\x01\n\x17\x43reateForServiceAccount\x12;.yandex.cloud.iam.v1.CreateIamTokenForServiceAccountRequest\x1a+.yandex.cloud.iam.v1.CreateIamTokenResponse\"1\x82\xd3\xe4\x93\x02+\"&/iam/v1/tokens:createForServiceAccount:\x01*BV\n\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.iam_token_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam'
  _CREATEIAMTOKENREQUEST.oneofs_by_name['identity']._options = None
  _CREATEIAMTOKENREQUEST.oneofs_by_name['identity']._serialized_options = b'\300\3011\001'
  _CREATEIAMTOKENFORSERVICEACCOUNTREQUEST.fields_by_name['service_account_id']._options = None
  _CREATEIAMTOKENFORSERVICEACCOUNTREQUEST.fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _IAMTOKENSERVICE.methods_by_name['Create']._options = None
  _IAMTOKENSERVICE.methods_by_name['Create']._serialized_options = b'\202\323\344\223\002\023\"\016/iam/v1/tokens:\001*'
  _IAMTOKENSERVICE.methods_by_name['CreateForServiceAccount']._options = None
  _IAMTOKENSERVICE.methods_by_name['CreateForServiceAccount']._serialized_options = b'\202\323\344\223\002+\"&/iam/v1/tokens:createForServiceAccount:\001*'
  _globals['_CREATEIAMTOKENREQUEST']._serialized_start=162
  _globals['_CREATEIAMTOKENREQUEST']._serialized_end=257
  _globals['_CREATEIAMTOKENRESPONSE']._serialized_start=259
  _globals['_CREATEIAMTOKENRESPONSE']._serialized_end=350
  _globals['_CREATEIAMTOKENFORSERVICEACCOUNTREQUEST']._serialized_start=352
  _globals['_CREATEIAMTOKENFORSERVICEACCOUNTREQUEST']._serialized_end=434
  _globals['_IAMTOKENSERVICE']._serialized_start=437
  _globals['_IAMTOKENSERVICE']._serialized_end=765
# @@protoc_insertion_point(module_scope)
